//
//  QHVCCommonLogEntry.h
//  QHVCCommonKit
//
//  Created by deng on 2017/11/1.
//  Copyright © 2017年 qihoo.QHVCCommonKit. All rights reserved.
//

#import <Foundation/Foundation.h>

typedef NS_ENUM(NSInteger, QHVCLogLevel){//日志等级
    QHVC_LOG_LEVEL_TRACE = 0,
    QHVC_LOG_LEVEL_DEBUG = 1,
    QHVC_LOG_LEVEL_INFO  = 2,
    QHVC_LOG_LEVEL_WARN  = 3,
    QHVC_LOG_LEVEL_ERROR = 4,
    QHVC_LOG_LEVEL_ALARM = 5,
    QHVC_LOG_LEVEL_FATAL = 6,
    QHVC_LOG_LEVEL_NONE  = 7,
};

NS_ASSUME_NONNULL_BEGIN

@interface QHVCCommonLogEntry : NSObject

/// 创建日志对象，返回具体的日志ID
/// 该方法必须在该单元模块创建日志时优先调用。默认输出日志等级为QHVC_LOG_LEVEL_INFO级别
/// @param loggerIdentify 日志标识名字
+ (int)createLogger:(NSString *)loggerIdentify;

/// 设置日志回调方法
/// @param callback 回调方法
/// @param loggerId 日志ID
+ (void)setLoggerCallback:(void(^)(QHVCLogLevel level, NSString *data))callback
                 loggerId:(int)loggerId;

/// 设置控制台日志输出等级
/// @param loggerLevel 日志等级
/// @param loggerId 日志ID
+ (void)setLoggerLevel:(QHVCLogLevel)loggerLevel
              loggerId:(int)loggerId;

/// 设置日志输出文件夹
/// @param outputDirectory 输出文件夹
+ (void)setLoggerFileOutputDirectory:(nullable NSString *)outputDirectory;

/// 设置本地保存日志路径
/// @param loggerPath 日志路径
/// @param loggerId 日志ID
+ (void)setLoggerFilePath:(NSString *)loggerPath
                 loggerId:(int)loggerId;

/// 设置本地保存文件日志等级
/// @param loggerLevel 日志等级
/// @param loggerId 日志ID
+ (void)setLoggerFileLevel:(QHVCLogLevel)loggerLevel
                  loggerId:(int)loggerId;

/// 打印日志
/// @param loggerId 日志ID
/// @param loggerLevel 日志等级
/// @param content 日志内容
+ (void)printLogger:(int)loggerId
        loggerLevel:(QHVCLogLevel)loggerLevel
            content:(NSString *)content;

/// 打印日志
/// @param loggerId 日志ID
/// @param loggerLevel 日志等级
/// @param content 日志内容
/// @param dict 待打印的数据字典
+ (void)printLogger:(int)loggerId
        loggerLevel:(QHVCLogLevel)loggerLevel
            content:(NSString *)content
               dict:(NSDictionary *)dict;

/// 传输层日志ID，系统默认创建
+ (int)transportLoggerId;

/// 播放器日志ID，系统默认创建
+ (int)playerLoggerId;

/// 推流采集端日志ID，系统默认创建
+ (int)cameraLoggerId;

@end

NS_ASSUME_NONNULL_END
