//
//  QHVCDLANMediaController.h
//  QHVCScreenCastKit
//
//  Created by yinchaoyu on 2018/8/16.
//  Copyright © 2018年 qihoo 360. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "QHVCScreenCastDefines.h"

@protocol QHVCDLANMediaControllerDelegate <NSObject>

@required

/**
 发现投屏播放设备

 @param renderName 设备名称
 @param UUID 设备唯一标识符
 */
- (void)onMediaRenderAdd:(nonnull NSString *)renderName renderUUID:(nonnull NSString *)UUID;


/**
 投屏播放设备退出了投屏环境

 @param renderName 设备名称
 @param UUID 设备唯一标识符
 */
- (void)onMediaRenderRemoved:(nonnull NSString *)renderName renderUUID:(nonnull NSString *)UUID;
@optional

/**
 播放请求结果回调

 @param bSuccess 是否成功
 */
- (void)onPlayResult:(BOOL)bSuccess;

/**
 设置静音请求回调

 @param bSuccess 是否设置成功
 */
- (void)onSetMuteResult:(BOOL)bSuccess;

/**
 获取设备静音状态回调

 @param bSuccess 是否成功
 @param bMute 静音状态
 */
- (void)onGetMuteResult:(BOOL)bSuccess mute:(BOOL)bMute;

/**
 获取播放进度回调

 @param bSuccess 是否成功
 @param position 当前播放位置，单位秒
 */
- (void)onGetPositionResult:(BOOL)bSuccess position:(NSUInteger)position;

/**
 设置设备音量

 @param bSuccess 是否成功
 */
- (void)onSetVolumeResult:(BOOL)bSuccess;

/**
 获取设备音量

 @param bSuccess 是否成功
 @param volume 当前音量
 */
- (void)onGetVolumeResult:(BOOL)bSuccess volume:(NSUInteger)volume;

@end

@interface QHVCDLANMediaController : NSObject

@property (nonatomic, weak) _Null_unspecified id<QHVCDLANMediaControllerDelegate> delegate;

/**
 开始扫描设备

 @return 错误码
 */
- (QHVCScreenCastError)start;


/**
 开始扫描设备并启动MediaServer,同时支持本地文件投屏和url投屏
 
 @param path mediaserver 文件根目录
 @return 错误码
 */
- (QHVCScreenCastError)startMediaServerWithFileRoot:(nonnull NSString *)path;

/**
 设置当前的投屏设备

 @param renderUUID 设备uuid
 @return 错误码
 */
- (QHVCScreenCastError)setMediaRender:(nonnull NSString *)renderUUID;

/**
 播放

 @param URL 要播放的URL
 @return 错误码
 */
- (QHVCScreenCastError)playWithURL:(nonnull NSURL *)URL;


/**
 播放本地文件

 @param fileName 文件名
 @return 错误码
 */
- (QHVCScreenCastError)playWithLocalFile:(nonnull NSString *)fileName;

/**
 seek

 @param pos 播放位置，单位秒
 @return 错误码
 */
- (QHVCScreenCastError)seek:(NSTimeInterval)pos;

/**
 暂停

 @return 错误码
 */
- (QHVCScreenCastError)pause;

/**
 暂停后继续播放

 @return 错误码
 */
- (QHVCScreenCastError)resume;

/**
 推出投屏

 @return 错误码
 */
- (QHVCScreenCastError)stop;

/**
 设置静音

 @param bMute 是否静音，静音：YES， 非静音：NO
 @return 错误码
 */
- (QHVCScreenCastError)setMute:(BOOL)bMute;

/**
 获取静音状态，状态在onGetMuteResult中返回

 @return 错误码
 */
- (QHVCScreenCastError)getMute;

/**
 设置音量

 @param volume 音量值 1～100
 @return 错误码
 */
- (QHVCScreenCastError)setVolume:(NSUInteger)volume;

/**
 获取当前音量，音量在delegate中返回

 @return 错误码
 */
- (QHVCScreenCastError)getVolume;

/**
 获取当前播放进度

 @return 错误码
 */
- (QHVCScreenCastError)getPosition;

@end
