//
//  QHVCMediaPlayback.h
//  QHVCScreenCastKit
//
//  Created by yinchaoyu on 2018/10/18.
//  Copyright © 2018 qihoo 360. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>

NS_ASSUME_NONNULL_BEGIN

typedef NS_ENUM(NSInteger, QHVCPlayerScalingMode) {
    QHVCPlayerScalingModeNone,       // No scaling
    QHVCPlayerScalingModeAspectFit,  // Uniform scale until one dimension fits
    QHVCPlayerScalingModeAspectFill, // Uniform scale until the movie fills the visible bounds. One dimension may have clipped contents
    QHVCPlayerScalingModeFill        // Non-uniform scale. Both render dimensions will exactly match the visible bounds
};

typedef NS_ENUM(NSInteger, QHVCPlayerPlaybackState) {
    QHVCPlayerPlaybackStateStopped,
    QHVCPlayerPlaybackStatePlaying,
    QHVCPlayerPlaybackStatePaused,
    QHVCPlayerPlaybackStateInterrupted,
    QHVCPlayerPlaybackStateSeekingForward,
    QHVCPlayerPlaybackStateSeekingBackward
};

typedef NS_OPTIONS(NSUInteger, QHVCPlayerLoadState) {
    QHVCPlayerLoadStateUnknown        = 0,
    QHVCPlayerLoadStatePlayable       = 1 << 0,
    QHVCPlayerLoadStatePlaythroughOK  = 1 << 1, // Playback will be automatically started in this state when shouldAutoplay is YES
    QHVCPlayerLoadStateStalled        = 1 << 2, // Playback will be automatically paused in this state, if started
};

typedef NS_ENUM(NSInteger, IQHVCPlayerFinishReason) {
    QHVCPlayerFinishReasonPlaybackEnded,
    QHVCPlayerFinishReasonPlaybackError,
    QHVCPlayerFinishReasonUserExited
};

@protocol QHVCMediaPlayback <NSObject>

- (void)prepareToPlay;
- (void)play;
- (void)pause;
- (void)stop;
- (BOOL)isPlaying;
- (void)shutdown;
- (void)setPauseInBackground:(BOOL)pause;

@property(nonatomic, readonly)  UIView *view;
@property(nonatomic)            NSTimeInterval currentPlaybackTime;
@property(nonatomic, readonly)  NSTimeInterval duration;
@property(nonatomic, readonly)  NSTimeInterval playableDuration;
@property(nonatomic, readonly)  NSInteger bufferingProgress;

@property(nonatomic, readonly)  BOOL isPreparedToPlay;
@property(nonatomic, readonly)  QHVCPlayerPlaybackState playbackState;
@property(nonatomic, readonly)  QHVCPlayerLoadState loadState;
@property(nonatomic, readonly) int isSeekBuffering;
@property(nonatomic, readonly) int isAudioSync;
@property(nonatomic, readonly) int isVideoSync;

@property(nonatomic, readonly) int64_t numberOfBytesTransferred;

@property(nonatomic, readonly) CGSize naturalSize;
@property(nonatomic) QHVCPlayerScalingMode scalingMode;
@property(nonatomic) BOOL shouldAutoplay;

@property (nonatomic) BOOL allowsMediaAirPlay;
@property (nonatomic) BOOL isDanmakuMediaAirPlay;
@property (nonatomic, readonly) BOOL airPlayMediaActive;

@property (nonatomic) float playbackRate;
@property (nonatomic) float playbackVolume;

- (UIImage *)thumbnailImageAtCurrentTime;

#pragma mark Notifications

#ifdef __cplusplus
#define QHVC_EXTERN extern "C" __attribute__((visibility ("default")))
#else
#define QHVC_EXTERN extern __attribute__((visibility ("default")))
#endif

// -----------------------------------------------------------------------------
//  QHVCMediaPlayback.h

// Posted when the prepared state changes of an object conforming to the MPMediaPlayback protocol changes.
// This supersedes MPMoviePlayerContentPreloadDidFinishNotification.
QHVC_EXTERN NSString *const QHVCPlayerPlaybackIsPreparedToPlayDidChangeNotification;

// -----------------------------------------------------------------------------
//  MPMoviePlayerController.h
//  Movie Player Notifications

// Posted when the scaling mode changes.
QHVC_EXTERN NSString* const QHVCPlayerScalingModeDidChangeNotification;

// Posted when movie playback ends or a user exits playback.
QHVC_EXTERN NSString* const QHVCPlayerPlaybackDidFinishNotification;
QHVC_EXTERN NSString* const QHVCPlayerPlaybackDidFinishReasonUserInfoKey; // NSNumber (IJKMPMovieFinishReason)

// Posted when the playback state changes, either programatically or by the user.
QHVC_EXTERN NSString* const QHVCPlayerPlaybackStateDidChangeNotification;

// Posted when the network load state changes.
QHVC_EXTERN NSString* const QHVCPlayerLoadStateDidChangeNotification;

// Posted when the movie player begins or ends playing video via AirPlay.
QHVC_EXTERN NSString* const QHVCPlayerIsAirPlayVideoActiveDidChangeNotification;

// -----------------------------------------------------------------------------
// Movie Property Notifications

// Calling -prepareToPlay on the movie player will begin determining movie properties asynchronously.
// These notifications are posted when the associated movie property becomes available.
QHVC_EXTERN NSString* const QHVCPlayerNaturalSizeAvailableNotification;

// -----------------------------------------------------------------------------
//  Extend Notifications

QHVC_EXTERN NSString *const QHVCPlayerVideoDecoderOpenNotification;
QHVC_EXTERN NSString *const QHVCPlayerFirstVideoFrameRenderedNotification;
QHVC_EXTERN NSString *const QHVCPlayerFirstAudioFrameRenderedNotification;
QHVC_EXTERN NSString *const QHVCPlayerFirstAudioFrameDecodedNotification;
QHVC_EXTERN NSString *const QHVCPlayerFirstVideoFrameDecodedNotification;
QHVC_EXTERN NSString *const QHVCPlayerOpenInputNotification;
QHVC_EXTERN NSString *const QHVCPlayerFindStreamInfoNotification;
QHVC_EXTERN NSString *const QHVCPlayerComponentOpenNotification;

QHVC_EXTERN NSString *const QHVCPlayerDidSeekCompleteNotification;
QHVC_EXTERN NSString *const QHVCPlayerDidSeekCompleteTargetKey;
QHVC_EXTERN NSString *const QHVCPlayerDidSeekCompleteErrorKey;
QHVC_EXTERN NSString *const QHVCPlayerDidAccurateSeekCompleteCurPos;
QHVC_EXTERN NSString *const QHVCPlayerAccurateSeekCompleteNotification;
QHVC_EXTERN NSString *const QHVCPlayerSeekAudioStartNotification;
QHVC_EXTERN NSString *const QHVCPlayerSeekVideoStartNotification;

@end

NS_ASSUME_NONNULL_END
